@@ -125,6 +125,18 @@ para_cima = [0,-1]
 para_baixo = [0,1]
 direcao_nula = [0,0]
 
+#define gravidade do programa e aplica nos objetos
+gravidade = 10
+def aplicar_gravidade():
+    while rodar_threading:
+        pygame.time.Clock().tick( 10 )
+        for objeto in lista_de_objetos:
+            if( objeto.cai and not objeto.pousou ):
+                objeto._velocidade_de_queda += gravidade
+
+t_aplicar_gravidade = threading.Thread( target = aplicar_gravidade )
+t_aplicar_gravidade.start()
+
 #Classe usada para definir objetos que aparecerão no programa
 #Deve ser passada uma imagem para que o objeto seja criado
 #Demais características devem ser alteradas após a criação do objeto
@@ -132,18 +144,14 @@ class Objeto():
     def __init__(self, nome_da_imagem = 'galinha'):
         #Para threading do objeto quando apagado
         self._existe = True
-        #define imagem
+        #define imagem 
         self.nome_da_imagem = nome_da_imagem
-        if( '.' not in self.nome_da_imagem ):
-            self.nome_da_imagem += '.png'
-            self.nome_da_imagem = os.path.join( pasta_das_imagens, self.nome_da_imagem)
-        self.imagem = pygame.image.load(self.nome_da_imagem)
         
         #define área da imagem
         self.area_da_imagem = self.imagem.get_rect()
 
         #usado quando o tamanho da imagem é alterado
-        self.manter_proporção = True
+        self.manter_proporcao = True
 
         #A velocidade define a taxa com que o objeto se move na tela
         #Pode ser lida como pixels por segundo
@@ -185,6 +193,16 @@ class Objeto():
         #Começa a rodar função mover em paralelo
         self.threading_mover.start()
 
+        #Usados para a gravidade
+        self.cai = False
+        self._velocidade_de_queda = 0
+
+        #Define objeto usado para rodar a função mover em paralelo
+        self.threading_cair = threading.Thread(target= self._cair )
+
+        #Começa a rodar função mover em paralelo
+        self.threading_cair.start()
+
         #funcao com movimentos
         self.movimentos_paralelos = []
 
@@ -200,12 +218,53 @@ class Objeto():
             self.area_da_imagem.height = 0
             self.direita = -10
             self.base = -10
-            
+
+    #nome da imagem
+    @property
+    def nome_da_imagem(self):
+        return _nome_da_imagem
+
+    @nome_da_imagem.setter
+    def nome_da_imagem(self, nome_da_imagem ):
+        self._nome_da_imagem = nome_da_imagem
+        if( '.' not in self._nome_da_imagem ):
+            self._nome_da_imagem += '.png'
+            self._nome_da_imagem = os.path.join( pasta_das_imagens, self._nome_da_imagem)
+        self.imagem = pygame.image.load(self._nome_da_imagem)
+
     #mostra se objeto existe
     @property
     def existe(self ):
         return self._existe
 
+
+    #colisões
+    def realizar_colisoes(self):            
+        if( self.solido ):
+            for objeto in lista_de_objetos:
+                if( objeto.solido ):
+                    if( self.borda_direita.colliderect( objeto.borda_esquerda ) ):
+                        self.direita = objeto.esquerda + 1
+                    if( self.borda_esquerda.colliderect( objeto.borda_direita ) ):
+                        self.esquerda = objeto.direita - 1
+                    if( self.borda_superior.colliderect( objeto.borda_inferior ) ):
+                        self.topo = objeto.base - 1
+                    if( self.borda_inferior.colliderect( objeto.borda_superior ) ):
+                        self.base = objeto.topo + 1
+
+                    
+        #manter na tela
+        if(self.manter_na_tela):
+            if( self.topo < 0 ):
+                self.topo = -1
+            if( self.esquerda < 0 ):
+                self.esquerda = -1
+            if( self.base > tela.altura ):
+                self.base = tela.altura + 1
+            if( self.direita > tela.largura):
+                self.direita = tela.largura +1
+
+
     #Função que move o objeto criado na tela    
     def mover(self):
         global rodar_threading
@@ -249,31 +308,51 @@ class Objeto():
             #movimento através da direção definida
             self.area_da_imagem.move_ip( self.direcao[0], \
                                          self.direcao[1])
-                    
-            #colisões
-            if( self.solido ):
-                for objeto in self.colisoes:
-                    if( objeto.solido ):
-                        if( self.borda_direita.colliderect( objeto.borda_esquerda ) ):
-                            self.direita = objeto.esquerda + 1
-                        if( self.borda_esquerda.colliderect( objeto.borda_direita ) ):
-                            self.esquerda = objeto.direita - 1
-                        if( self.borda_superior.colliderect( objeto.borda_inferior ) ):
-                            self.topo = objeto.base - 1
-                        if( self.borda_inferior.colliderect( objeto.borda_superior ) ):
-                            self.base = objeto.topo + 1
-                
-            #manter na tela
-            if(self.manter_na_tela):
-                if( self.topo < 0 ):
-                    self.topo = -1
-                if( self.esquerda < 0 ):
-                    self.esquerda = -1
-                if( self.base > tela.altura ):
-                    self.base = tela.altura + 1
-                if( self.direita > tela.largura):
-                    self.direita = tela.largura +1
+
+            #realiza colisões
+            self.realizar_colisoes()
+    
+    def _pousar(self):
+        global lista_de_objetos
+        if( self.pousou ):
+            self._velocidade_de_queda = 0
+
+    @property
+    def pousou(self):
+        global lista_de_objetos
+        
+        esta_sobre_um_objeto = False
+        for objeto in lista_de_objetos:
+            esta_sobre_um_objeto = esta_sobre_um_objeto or self.tocou_em_cima( objeto ) 
+        
+        pousou =  ( self.base >= tela.altura or esta_sobre_um_objeto )
+        return pousou
                 
+
+    def _cair(self):
+        clock_padrao = 100
+        while rodar_threading:
+            if( not self.cai ):
+                pygame.time.Clock().tick( clock_padrao )
+                continue
+            elif( self._velocidade_de_queda > 0 ):
+                pygame.time.Clock().tick( self._velocidade_de_queda )
+                self.y += 1
+
+            elif( self._velocidade_de_queda == 0):
+                pygame.time.Clock().tick( clock_padrao )
+                continue
+            else:
+                pygame.time.Clock().tick( -self._velocidade_de_queda )
+                self.y -= 1
+
+            self._pousar()
+            self.realizar_colisoes()
+
+    def pular(self, velocidade_de_pulo=100, delay=0.1 ):
+        self._velocidade_de_queda -= velocidade_de_pulo
+        esperar(delay)
+
     #muda tamanho da imagem
     @property
     def largura(self):
@@ -281,7 +360,7 @@ class Objeto():
 
     @largura.setter
     def largura(self, largura):
-        if(self.manter_proporção ):
+        if(self.manter_proporcao ):
             altura = int( self.altura*largura/self.largura)
             self.imagem= pygame.transform.scale( self.imagem,
                                                  [largura, altura] )
@@ -298,7 +377,7 @@ class Objeto():
 
     @altura.setter
     def altura(self, altura):
-        if( self.manter_proporção ):
+        if( self.manter_proporcao ):
             largura = int( self.largura*altura/self.altura)
             self.imagem= pygame.transform.scale( self.imagem, [largura, altura] )
             self.area_da_imagem.width = largura
